@@ -1,12 +1,13 @@
-use clap::{crate_version, App, Arg};
+use clap::{App, Arg, crate_version};
 use dns_lookup::lookup_host;
-use mb_dev::shell_exec;
+
+use mb_dev::shell;
 
 fn main() {
     let matches = App::new("dkh")
         .about("Delete hosts from ~/.ssh/known_hosts")
         .version(crate_version!())
-        .arg(Arg::new("hosts").multiple(true).required(true))
+        .arg(Arg::new("hosts").multiple_values(true).required(true))
         .get_matches();
 
     for host in matches.values_of("hosts").unwrap().collect::<Vec<_>>() {
@@ -15,11 +16,11 @@ fn main() {
 }
 
 fn delete_host(host: &str) {
-    shell_exec(format!("ssh-keygen -R {}", host).as_str());
+    shell(&format!("ssh-keygen -R {}", host));
 
     if let Ok(ips) = lookup_host(host) {
         for h in ips.iter() {
-            shell_exec(format!("ssh-keygen -R {}", h.to_string()).as_str());
+            shell(&format!("ssh-keygen -R {}", h));
         }
     }
 }
