@@ -1,5 +1,6 @@
-use clap::{crate_version, App, AppSettings};
-use mb_dev::{exit, shell_exec, user_input};
+use clap::{App, AppSettings, crate_version};
+
+use mb_dev::{exit, shell, user_input};
 
 fn main() {
     let matches = App::new("hcloud helper")
@@ -12,7 +13,7 @@ fn main() {
         .get_matches();
 
     match matches.subcommand() {
-        Some(("list", _)) => shell_exec("hcloud server list -o columns=name,ipv4,datacenter,status,type,volumes"),
+        Some(("list", _)) => shell("hcloud server list -o columns=name,ipv4,datacenter,status,type,volumes"),
         Some(("rebuild", m)) => {
             let server = m.value_of("server").unwrap();
 
@@ -23,7 +24,8 @@ fn main() {
                     exit(&format!("Confirm failed! {} != {}", server, confirm))
                 }
             }
-            shell_exec(&format!("hcloud server rebuild '{}' --image=ubuntu-20.04", server))
+            shell(&format!("hcloud server rebuild '{}' --image=ubuntu-20.04", server));
+            shell(&format!("dkh {}", server));
         }
         Some(("delete", m)) => {
             let server = m.value_of("server").unwrap();
@@ -34,7 +36,7 @@ fn main() {
             if server != confirm {
                 exit(&format!("Confirm failed! {} != {}", server, confirm))
             }
-            shell_exec(&format!("hcloud server delete '{}'", server))
+            shell(&format!("hcloud server delete '{}'", server))
         }
         _ => println!("unknown subcommand"),
     }
